@@ -39,10 +39,10 @@ namespace Kwave
 	    Delay();
 
 	    /** Destructor */
-	    virtual ~Delay();
+            virtual ~Delay() Q_DECL_OVERRIDE;
 
 	    /** does the calculation */
-	    void goOn() Q_DECL_OVERRIDE;
+            virtual void goOn() Q_DECL_OVERRIDE;
 
 	signals:
 	    /** emits a block with delayed wave data */
